@@ -54,5 +54,19 @@ import pandas as pd
 # st.plotly_chart(fig, use_container_width=True)
 ''' _This_ is some __Markdown__ '''
 
+with st.form("my_form"):
+    st.write("Inside the form")
+    slider_val = st.slider("Form slider")
+    st.write("This is inside the container")
+    submit_button = st.form_submit_button(label="✨ 启动!")
+    print(f"submit_button: {submit_button}")
+
+
+st.write("---")
+
+with st.expander(label="json结果展示",expanded=False):
+    st.write({'a': 666})
+
+
 
 
